==> tine20-allinone_2019.12.5.tar.bz2: ActiveSync/js/ActiveSync-lang-pl-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of ActiveSync **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:48+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Polish (http://www.transifex.com/tine20/tine20/language/pl/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: pl\nPlural-Forms: nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "SyncDevice, SyncDevices"
: [
  "Połączone urządzenia"
 ,"Połączone urządzenia"
 ,"Połączone urządzenia"
 ,"Połączone urządzenia"

]
, "Sync Devices"
: "Połącz urządzenia"

, "ID"
: "Id"

, "Device ID"
: "Id urządzenia"

, "Devicetype"
: "Typ urządzenia"

, "Owner"
: "Właściciel"

, "Policy"
: "Polityka"

, "AS Version"
: "Wersja AS"

, "Useragent"
: "Useragent"

, "Model"
: "Model"

, "IMEI"
: "IMEI"

, "Friendly Name"
: "Przyjazna nazwa"

, "OS"
: "System operacyjny"

, "OS Language"
: "Język systemu operacyjnego"

, "Phonenumber"
: "Numer telefonu"

, "Ping Lifetime"
: "Czas odpowiedzi ping."

, "Ping Folder"
: "Katalog ping"

, "Remote Wipe"
: "Zdalne usuwanie"

, "Calendarfilter"
: "Filtr kalendarza"

, "Contactsfilter"
: "Filtr kontaktów"

, "Emailfilter"
: "Filtr poczty"

, "Tasksfilter"
: "Filtr zadań"

, "Last Ping"
: "Ostatni ping"

, "Remote Reset Device"
: ""

, "Please Confirm"
: ""

, "Do you really want to wipe the selected devices? All personal data will be removed and the device is reset to factory settings!"
: ""

, "Quicksearch"
: "Szybkie wyszukiwanie"

, "Device, Devices"
: [
  "Urządzenie"
 ,"urządzenia"
 ,"urządzenia"
 ,"urządzenia"

]
, "Devices"
: "Urządzenia"

, "Active Sync"
: "Zdalna synchronizacja"

, "Select a Device"
: "Wybierz urządzenie"

, "No ActiveSync Device registered"
: "Usługa ActiveSync niezarejestrowana"

, "Set as {0} Filter"
: "Ustaw jako filtr: {0}"

, "Resetted Sync Filter"
: "Zresetowany filtr synchronizacji"

, "{0} filter for device \"{1}\" is now \"{2}\""
: "Filtrem {0} dla urządzenia \"{1}\"  jest teraz \"{2}\""

, "resetted"
: "zresetowane"

, "Set Sync Filter"
: "Ustaw filtr synchronizacji"

, "Default Addressbook"
: "Domyślna książka adresowa"

, "The default addressbook to create new contacts in."
: "Domyślna książka adresowa z nowymi kontaktami"

, "Default Calendar"
: "Domyślny kalendarz"

, "The default calendar to create new events in."
: "Domyślny kalendarz z nowymi terminami"

, "Default Task List"
: "Domyślna lista zadań"

, "The default task list to create new tasks in."
: "Domyślna lista dla nowo tworzonych zadań"

, "Default policy for new devices"
: "Domyślna polityka dla nowych urządzeń"

, "Enter the id of the policy to apply to newly created devices."
: "Wpisz id polityki, aby przypisać ją do nowo dodanych urządzeń."

, "Disable Access Log"
: "Wyłącz dziennik logowania"

, "Disable ActiveSync Access Log creation."
: "Wyłącz dziennik logowania dla ActiveSync"

, "Filter timeslot for emails"
: "Filtruj przedział czasu dla poczty"

, "For how long in the past the emails should be synchronized."
: "Jak daleko wstecz należy zsynchronizować pocztę."

, "Filter timeslot for events"
: "Filtruj przydział czasu dla wydarzeń"

, "For how long in the past the events should be synchronized."
: "Jak daleko wprzód należy zsynchronizować wydarzenia."

, "Manage ActiveSync devices"
: "Brak urządzenia połączonego z usługą ActiveSync"

, "See, edit and delete ActiveSync devices"
: "Podglądaj, edytuj i usuwaj urządzenia dla usługi ActiveSync"

, "Reset ActiveSync devices"
: ""

, "Remotely reset ActiveSync devices to factory state, deleting all data"
: ""

, "Default Policy"
: "Domyślna polityka"

, "Default Policy installed during setup"
: "Domyślna polityka określona podczas definiowania ustawień"

, "SyncDevice"
: "Połączone urządzenia"

, "Device"
: "Urządzenie"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: ActiveSync/js/ActiveSync-lang-pl-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of ActiveSync **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:48+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Polish (http://www.transifex.com/tine20/tine20/language/pl/)\nLanguage: pl\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Default Address book"
: ""

, "The default address book to create new contacts in."
: ""

, "Default Calendar"
: "Domyślny kalendarz"

, "The default calendar to create new events in."
: "Domyślny kalendarz z nowymi terminami"

, "Default Task List"
: "Domyślna lista zadań"

, "The default task list to create new tasks in."
: "Domyślna lista dla nowo tworzonych zadań"

, "Sync Devices"
: "Połącz urządzenia"

, "Device ID"
: "Id urządzenia"

, "Devicetype"
: "Typ urządzenia"

, "Owner"
: "Właściciel"

, "Policy"
: "Polityka"

, "ActiveSync Version"
: ""

, "User agent"
: ""

, "Model"
: "Model"

, "IMEI"
: "IMEI"

, "Friendly Name"
: "Przyjazna nazwa"

, "OS"
: "System operacyjny"

, "OS Language"
: "Język systemu operacyjnego"

, "Phonenumber"
: "Numer telefonu"

, "Sync Device, Sync Devices"
: [
  ""
 ,""
 ,""
 ,""

]
, "Device, Devices"
: [
  "Urządzenie"
 ,"urządzenia"
 ,"urządzenia"
 ,"urządzenia"

]
, "Devices"
: "Urządzenia"

, "Active Sync"
: "Zdalna synchronizacja"

, "Select a Device"
: "Wybierz urządzenie"

, "No ActiveSync Device registered"
: "Usługa ActiveSync niezarejestrowana"

, "Set as {0} Filter"
: "Ustaw jako filtr: {0}"

, "Resetted Sync Filter"
: "Zresetowany filtr synchronizacji"

, "{0} filter for device \"{1}\" is now \"{2}\""
: "Filtrem {0} dla urządzenia \"{1}\"  jest teraz \"{2}\""

, "resetted"
: "zresetowane"

, "Set Sync Filter"
: "Ustaw filtr synchronizacji"

, "ID"
: "Id"

, "Device Type"
: ""

, "Operating System"
: ""

, "Phone Number"
: ""

, "Ping Lifetime"
: "Czas odpowiedzi ping."

, "Ping Folder"
: "Katalog ping"

, "Remote Wipe"
: "Zdalne usuwanie"

, "Calendar Filter"
: ""

, "Contacts Filter"
: ""

, "E-mail Filter"
: ""

, "Tasks Filter"
: ""

, "Last Ping"
: "Ostatni ping"

, "Monitor Last Ping"
: ""

, "Remote Device Reset"
: ""

, "Please Confirm"
: ""

, "Do you really want to wipe the selected devices? All personal data will be removed and the device will be reset to factory settings!"
: ""

, "Quicksearch"
: "Szybkie wyszukiwanie"

, "Default Policy"
: "Domyślna polityka"

, "Default Policy installed during setup"
: "Domyślna polityka określona podczas definiowania ustawień"

, "Default policy for new devices"
: "Domyślna polityka dla nowych urządzeń"

, "Enter the id of the policy to apply to newly created devices."
: "Wpisz id polityki, aby przypisać ją do nowo dodanych urządzeń."

, "User Agent Deny List"
: ""

, "Array of regular expressions of User-Agent strings"
: ""

, "Disable Access Log"
: "Wyłącz dziennik logowania"

, "Disable ActiveSync Access Log creation."
: "Wyłącz dziennik logowania dla ActiveSync"

, "Filter timeslot for e-mails"
: ""

, "For how long in the past the e-mails should be synchronized."
: ""

, "Filter timeslot for events"
: "Filtruj przydział czasu dla wydarzeń"

, "For how long in the past the events should be synchronized."
: "Jak daleko wprzód należy zsynchronizować wydarzenia."

, "Manage ActiveSync devices"
: "Brak urządzenia połączonego z usługą ActiveSync"

, "See, edit and delete ActiveSync devices"
: "Podglądaj, edytuj i usuwaj urządzenia dla usługi ActiveSync"

, "Reset ActiveSync devices"
: ""

, "Remotely reset ActiveSync devices to factory state, deleting all data"
: ""












, "Sync Device"
: ""

, "Device"
: "Urządzenie"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
